@@ -1,6 +1,6 @@
 package Text::Todo;
 
-# $AFresh1: Todo.pm,v 1.27 2010/02/16 01:13:12 andrew Exp $
+# $AFresh1: Todo.pm,v 1.26 2010/02/14 06:08:07 andrew Exp $
 
 use warnings;
 use strict;
@@ -10,7 +10,7 @@ use Class::Std::Utils;
 use Text::Todo::Entry;
 use File::Spec;
 
-use version; our $VERSION = qv('0.2.0');
+use version; our $VERSION = qv('0.2.1');
 
 {
 
@@ -110,7 +110,7 @@ use version; our $VERSION = qv('0.2.0');
             if ( my ( $pre, $post )
                 = $path_of{$ident}{$type} =~ /^(.*)$1(.*)\.txt$/ixms )
             {
-                foreach my $f qw( todo done report ) {
+                foreach my $f (qw( todo done report )) {
                     if ( !defined $path_of{$ident}{ $f . '_file' } ) {
                         $path_of{$ident}{ $f . '_file' }
                             = $pre . $f . $post . '.txt';
